@@ -20,8 +20,8 @@
 //TQt includes
 #include <tqptrlist.h>
 
-//KDE includes
-#include <klocale.h>
+//TDE includes
+#include <tdelocale.h>
 
 //initialize static language list
 CLanguageMgr::LanguageList CLanguageMgr::m_langList;
@@ -95,10 +95,10 @@ const CLanguageMgr::LangMap& CLanguageMgr::availableLanguages() {
 
 		for (ListCSwordModuleInfo::iterator it(mods.begin()); it != end_it; ++it) {
 			//   for (CSwordModuleInfo* m = mods.first(); m; m = mods.next()) {
-			abbrev = (*it)->module()->Lang();
+			const char* mod = (*it)->module()->Lang();
 
-			if (abbrev && !abbrevs.contains(abbrev)) {
-				abbrevs.append( abbrev );
+			if (mod && !abbrevs.contains(mod)) {
+				abbrevs.append( mod );
 			}
 		};
 
