@@ -141,7 +141,7 @@ private:
 };
 
 class CDisplayConnections : public TQObject {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	CDisplayConnections( CDisplay* parent );
