@@ -23,7 +23,7 @@
 
 //TQt includes
 
-//KDE includes
+//TDE includes
 #include <tdeaction.h>
 #include <tdeaccel.h>
 #include <tdelocale.h>
@@ -110,37 +110,37 @@ void CCommentaryReadWindow::initActions() {
 	new TDEAction(
 		i18n("Next book"),
 		CResMgr::displaywindows::bibleWindow::nextBook::accel,
-		TQT_TQOBJECT(this), TQT_SLOT(nextBook()),
+		this, TQ_SLOT(nextBook()),
 		actionCollection(), "nextBook"
 	);
 	new TDEAction(
 		i18n("Previous book"),
 		CResMgr::displaywindows::bibleWindow::previousBook::accel,
-		TQT_TQOBJECT(this), TQT_SLOT(previousBook()),
+		this, TQ_SLOT(previousBook()),
 		actionCollection(), "previousBook"
 	);
 	new TDEAction(
 		i18n("Next chapter"),
 		CResMgr::displaywindows::bibleWindow::nextChapter::accel,
-		TQT_TQOBJECT(this), TQT_SLOT(nextChapter()),
+		this, TQ_SLOT(nextChapter()),
 		actionCollection(), "nextChapter"
 	);
 	new TDEAction(
 		i18n("Previous chapter"),
 		CResMgr::displaywindows::bibleWindow::previousChapter::accel,
-		TQT_TQOBJECT(this), TQT_SLOT(previousChapter()),
+		this, TQ_SLOT(previousChapter()),
 		actionCollection(), "previousChapter"
 	);
 	new TDEAction(
 		i18n("Next verse"),
 		CResMgr::displaywindows::bibleWindow::nextVerse::accel,
-		TQT_TQOBJECT(this), TQT_SLOT(nextVerse()),
+		this, TQ_SLOT(nextVerse()),
 		actionCollection(), "nextVerse"
 	);
 	new TDEAction(
 		i18n("Previous verse"),
 		CResMgr::displaywindows::bibleWindow::previousVerse::accel,
-		TQT_TQOBJECT(this), TQT_SLOT(previousVerse()),
+		this, TQ_SLOT(previousVerse()),
 		actionCollection(), "previousVerse"
 	);
 
