@@ -36,7 +36,7 @@ class TQHBoxLayout;
 * This class is used in the key chooser widgets
 */
 class CKCComboBox : public TQComboBox {
-	Q_OBJECT
+	TQ_OBJECT
   
 
 public:
@@ -71,7 +71,7 @@ signals:
   * @author The BibleTime team
   */
 class CKeyChooserWidget : public TQWidget  {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	/**
