@@ -85,14 +85,14 @@ CKeyReferenceWidget::CKeyReferenceWidget( CSwordBibleModuleInfo *mod, CSwordVers
 	updatelock = false;
 	m_module = mod;
 
-	setFocusPolicy(TQ_WheelFocus);
+	setFocusPolicy(TQWidget::WheelFocus);
 
 	// Erase button
 	KGuiItem erase_picture;
 	erase_picture.setIconName("locationbar_erase");
 	KPushButton *clearRef = new KPushButton(this);
 	clearRef->setGuiItem(erase_picture);
-	connect(clearRef, TQT_SIGNAL(clicked( ) ), TQT_SLOT(slotClearRef( )));
+	connect(clearRef, TQ_SIGNAL(clicked( ) ), TQ_SLOT(slotClearRef( )));
 
 	m_bookScroller = new CScrollerWidgetSet(this);
 
@@ -131,16 +131,16 @@ CKeyReferenceWidget::CKeyReferenceWidget( CSwordBibleModuleInfo *mod, CSwordVers
 
 	// signals and slots connections
 
-	connect(m_bookScroller, TQT_SIGNAL(change(int)), TQT_SLOT(slotBookChange(int)));
-	connect(m_bookScroller, TQT_SIGNAL(scroller_pressed()), TQT_SLOT(slotUpdateLock()));
-	connect(m_bookScroller, TQT_SIGNAL(scroller_released()), TQT_SLOT(slotUpdateUnlock()));
-	connect(m_textbox, TQT_SIGNAL(returnPressed()), TQT_SLOT(slotReturnPressed()));
-	connect(m_chapterScroller, TQT_SIGNAL(change(int)), TQT_SLOT(slotChapterChange(int)));
-	connect(m_chapterScroller, TQT_SIGNAL(scroller_pressed()), TQT_SLOT(slotUpdateLock()));
-	connect(m_chapterScroller, TQT_SIGNAL(scroller_released()), TQT_SLOT(slotUpdateUnlock()));
-	connect(m_verseScroller, TQT_SIGNAL(change(int)), TQT_SLOT(slotVerseChange(int)));
-	connect(m_verseScroller, TQT_SIGNAL(scroller_pressed()), TQT_SLOT(slotUpdateLock()));
-	connect(m_verseScroller, TQT_SIGNAL(scroller_released()), TQT_SLOT(slotUpdateUnlock()));
+	connect(m_bookScroller, TQ_SIGNAL(change(int)), TQ_SLOT(slotBookChange(int)));
+	connect(m_bookScroller, TQ_SIGNAL(scroller_pressed()), TQ_SLOT(slotUpdateLock()));
+	connect(m_bookScroller, TQ_SIGNAL(scroller_released()), TQ_SLOT(slotUpdateUnlock()));
+	connect(m_textbox, TQ_SIGNAL(returnPressed()), TQ_SLOT(slotReturnPressed()));
+	connect(m_chapterScroller, TQ_SIGNAL(change(int)), TQ_SLOT(slotChapterChange(int)));
+	connect(m_chapterScroller, TQ_SIGNAL(scroller_pressed()), TQ_SLOT(slotUpdateLock()));
+	connect(m_chapterScroller, TQ_SIGNAL(scroller_released()), TQ_SLOT(slotUpdateUnlock()));
+	connect(m_verseScroller, TQ_SIGNAL(change(int)), TQ_SLOT(slotVerseChange(int)));
+	connect(m_verseScroller, TQ_SIGNAL(scroller_pressed()), TQ_SLOT(slotUpdateLock()));
+	connect(m_verseScroller, TQ_SIGNAL(scroller_released()), TQ_SLOT(slotUpdateUnlock()));
 }
 
 void CKeyReferenceWidget::setModule(CSwordBibleModuleInfo *m) {
