@@ -22,7 +22,7 @@ class TQLabel;
  *
  * @author The team of BibleTime
  */
-class KStartupLogo : public TQWidget {
+class TDEStartupLogo : public TQWidget {
 public:
 	/**
 	* Create the splash screen and show it on the screen.
@@ -56,11 +56,11 @@ public:
 	static void lowerSplash();
 
 private:
-	KStartupLogo();
+	TDEStartupLogo();
 	void setText(const TQString text);
 	TQLabel* textLabel;
 
-	static KStartupLogo* startupLogo;
+	static TDEStartupLogo* startupLogo;
 };
 
 #endif
